@@ -16,4 +16,9 @@ class NoCallbackFoundException(Exception):
 class NoProtocolException(Exception):
     """ There is no protocol for the host"""
     def __init__(self, host):
-        super(NoProtocolException, self).__init__("No protocol given for host {}. You must provide http or https as protocol".format(host))
\ No newline at end of file
+        super(NoProtocolException, self).__init__("No protocol given for host {}. You must provide http or https as protocol".format(host))
+
+class RequestError(Exception):
+    """ The Request couldnt be handled """
+    def __init__(self, originalParams, exception, content):
+        super(RequestError, self).__init__("Request {} caused {} with {}".format(originalParams, exception, content))
\ No newline at end of file
